<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Database enrolment plugin installation.
 *
 * @package    enrol
 * @subpackage database
 * @copyright  2010 Petr Skoda {@link http://skodak.org}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

function xmldb_block_recommender_install() {
    global $DB;

    //Enable only the "popular activities on this website" service
    set_config('activity_enabled', 1, 'block_recommender');
    set_config('course_enabled', 0, 'block_recommender');
    set_config('bookmark_enabled', 0, 'block_recommender');

    // set up the activity service modules
    $mods = array('audiorecorder', 'dataplus', 'dualpane', 'externalquiz', 'feed', 'folder',
        'forumng', 'glossary', 'googlecollab', 'imscp', 'oublog', 'oucontent', 'ouelluminate',
        'ouwiki', 'page', 'portfolioact', 'questionnaire', 'quiz', 'refworks', 'resource', 'scorm',
        'sharedsubpage', 'subpage', 'url');
    $disabledmods = array('assignment', 'chat', 'choice', 'data', 'feedback', 'lesson', 'heading',
        'label', 'forum', 'repeatactivity', 'survey', 'wiki', 'workshop');
    foreach ($mods as $name) {
        set_config('activity_'.$name.'_enabled', 1, 'block_recommender');
        set_config('activity_'.$name.'_view', '', 'block_recommender');
        set_config('activity_'.$name.'_participate', '', 'block_recommender');
    }
    foreach ($disabledmods as $name) {
        set_config('activity_'.$name.'_enabled', 0, 'block_recommender');
        set_config('activity_'.$name.'_view', '', 'block_recommender');
        set_config('activity_'.$name.'_participate', '', 'block_recommender');
    }

    // set up the activity service participate log actions
    $array = array();
    $array['activity_quiz_participate'] = 'attempt';
    $array['activity_glossary_participate'] = 'add entry, update entry';
    $array['activity_forumng_participate'] = 'add reply, edit post, add discussion';
    $array['activity_oublog_participate'] = 'add comment, edit post, add post';
    $array['activity_ouwiki_participate'] = 'annotate, comment, edit';
    $array['activity_dataplus_participate'] = 'update, insert, update comment, insert comment';
    $array['activity_questionnaire_participate'] = 'submit';
    $array['activity_refworks_participate'] = 'createbib, createref';
    $array['activity_ouelluminate_participate'] = 'view meeting';

    // set up the activity service view log options
    $array['activity_assignment_view'] = 'view';
    $array['activity_glossary_view'] = 'view entry';
    $array['activity_forumng_view'] = 'view discussion';
    $array['activity_elluminate_view'] = 'view recording';

    foreach ($array as $name => $value) {
        set_config($name, $value, 'block_recommender');
    }

    // include these ones to stop the screen coming up
    // set up bookmark defaults
    set_config('bookmark_category_1', '', 'block_recommender');
    set_config('bookmark_category_2', '', 'block_recommender');
    set_config('bookmark_category_3', '', 'block_recommender');
    set_config('bookmark_displaytype', '', 'block_recommender');

    // set up popular courses
    set_config('course_role', 5, 'block_recommender');
    set_config('course_course_shortname_pattern', '', 'block_recommender');
    set_config('course_course_url', '', 'block_recommender');

    //finally add the block on all appropriate existing courses
    $targets = $DB->get_records('block_instances', array('blockname'=>'handylinks'));
    if ($targets) {
        foreach ($targets as $target) {
            $newblock = $target;
            $newblock->blockname = 'recommender';
            $newblock->id = null;
            $newblock->defaultweight = $target->defaultweight - 5;
            $DB->insert_record('block_instances', $newblock);
        }
    }

    return true;
}